@@ -21,7 +21,7 @@ public:
     Q_INVOKABLE void apply(const QString &name);
     Q_INVOKABLE int indexForScheme(const QString &name) const;
     Q_INVOKABLE QString nameForIndex(int index) const;
-    Q_INVOKABLE QVariantMap getUsefullColors(int index) const;
+    Q_INVOKABLE QStringList getUsefullColors(int index) const;
 
 private:
     KColorSchemeManager *c;
