@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2022-2024 Igor Mironchik <igor.mironchik@gmail.com>
+    SPDX-FileCopyrightText: 2022-2025 Igor Mironchik <igor.mironchik@gmail.com>
     SPDX-License-Identifier: MIT
 */
 
@@ -15,6 +15,7 @@
 #include <map>
 #include <memory>
 #include <string>
+#include <utility>
 #include <vector>
 
 // ICU include.
@@ -49,6 +50,7 @@
 namespace MD
 {
 
+//! Internal string, used to get virgin (original) string from transformed string.
 template<class String, class Char, class Latin1Char>
 class InternalStringT
 {
@@ -62,16 +64,26 @@ public:
     {
     }
 
+    //! \return Reference to string.
     String &asString()
     {
         return m_str;
     }
+
+    //! \return Reference to string.
     const String &asString() const
     {
         return m_str;
     }
 
-    String virginString(long long int pos = 0, long long int len = -1) const
+    //! \return Full virgin string.
+    const String &fullVirginString() const
+    {
+        return m_virginStr;
+    }
+
+    //! \return Virgin sub-string with position and length in the transformed string.
+    String virginSubString(long long int pos = 0, long long int len = -1) const
     {
         if (pos < 0) {
             pos = 0;
@@ -100,31 +112,34 @@ public:
             }
         }
 
-        if (len > 1) {
-            auto virginEndPos = virginPos(pos + len - 1);
+        auto virginEndPos = virginPos(pos + len - 1, true);
 
-            if (m_virginStr[virginEndPos] == Latin1Char('\t')) {
-                const auto spaces = countOfSpacesForTab(virginEndPos);
+        if (m_virginStr[virginEndPos] == Latin1Char('\t')) {
+            const auto spaces = countOfSpacesForTab(virginEndPos);
 
-                for (long long int i = 1; i < spaces; ++i) {
-                    if (virginPos(pos + len - 1 - i) != virginEndPos) {
-                        endStr = String(i, Latin1Char(' '));
-                        --virginEndPos;
-                        break;
-                    }
+            for (long long int i = 1; i < spaces; ++i) {
+                if (virginPos(pos + len - 1 - i) != virginEndPos) {
+                    endStr = String(i, Latin1Char(' '));
+                    --virginEndPos;
+                    break;
                 }
             }
-
-            return startStr + m_virginStr.sliced(virginStartPos, virginEndPos - virginStartPos + 1) + endStr;
-        } else {
-            return (startStr.isEmpty() ? String(1, m_virginStr[virginStartPos]) : String(1, Latin1Char(' ')));
         }
+
+        return startStr + m_virginStr.sliced(virginStartPos, virginEndPos - virginStartPos + 1) + endStr;
     }
 
-    long long int virginPos(long long int pos) const
+    //! \return Virgin position from transformed.
+    long long int virginPos(
+        //! Transformed position.
+        long long int pos,
+        //! If true will be return last virgin position before transformation.
+        //! For example if in virgin string 2 characters were replaced with 1,
+        //! we will receive position of second character if \p end is true.
+        bool end = false) const
     {
         for (auto it = m_changedPos.crbegin(), last = m_changedPos.crend(); it != last; ++it) {
-            pos = virginPosImpl(pos, *it);
+            pos = virginPosImpl(pos, *it, end);
         }
 
         return pos;
@@ -135,6 +150,7 @@ public:
         return m_str[position];
     }
 
+    //! Replace substring.
     InternalStringT &replaceOne(long long int pos, long long int size, const String &with)
     {
         const auto len = m_str.length();
@@ -150,6 +166,7 @@ public:
         return *this;
     }
 
+    //! Replace string.
     InternalStringT &replace(const String &what, const String &with)
     {
         String tmp;
@@ -185,6 +202,7 @@ public:
         return *this;
     }
 
+    //! Remove sub-string.
     InternalStringT &remove(long long int pos, long long int size)
     {
         const auto len = m_str.length();
@@ -197,15 +215,19 @@ public:
         return *this;
     }
 
+    //! \return Is this string empty?
     bool isEmpty() const
     {
         return m_str.isEmpty();
     }
+
+    //! \return Length of the string.
     long long int length() const
     {
         return m_str.length();
     }
 
+    //! \return Simplified string.
     InternalStringT simplified() const
     {
         if (isEmpty()) {
@@ -268,6 +290,7 @@ public:
         return result;
     }
 
+    //! Split string.
     std::vector<InternalStringT> split(const InternalStringT &sep) const
     {
         std::vector<InternalStringT> result;
@@ -311,6 +334,7 @@ public:
         return result;
     }
 
+    //! \return Sliced sub-string.
     InternalStringT sliced(long long int pos, long long int len = -1) const
     {
         InternalStringT tmp = *this;
@@ -324,6 +348,7 @@ public:
         return tmp;
     }
 
+    //! \return Right sub-string.
     InternalStringT right(long long int n) const
     {
         InternalStringT tmp = *this;
@@ -334,11 +359,13 @@ public:
         return tmp;
     }
 
+    //! Insert one character.
     InternalStringT &insert(long long int pos, Char ch)
     {
         return insert(pos, String(1, ch));
     }
 
+    //! Insert string.
     InternalStringT &insert(long long int pos, const String &s)
     {
         const auto len = m_str.length();
@@ -353,49 +380,52 @@ public:
     }
 
 private:
+    //! Transformed string.
     String m_str;
+    //! Virgin (original) string.
     String m_virginStr;
 
+    //! Auxiliary struct to store information about transformation.
     struct ChangedPos {
         long long int m_pos = -1;
         long long int m_oldLen = -1;
         long long int m_len = -1;
     };
 
+    //! Auxiliary struct to store information about transformation.
     struct LengthAndStartPos {
         long long int m_firstPos = 0;
         long long int m_length = 0;
     };
 
+    //! Information about transformations.
     std::vector<std::pair<LengthAndStartPos, std::vector<ChangedPos>>> m_changedPos;
 
 private:
-    long long int virginPosImpl(long long int pos, const std::pair<LengthAndStartPos, std::vector<ChangedPos>> &changed) const
+    long long int virginPosImpl(long long int pos, const std::pair<LengthAndStartPos, std::vector<ChangedPos>> &changed, bool end) const
     {
-        long long int p = 0;
-
         for (const auto &c : changed.second) {
-            if (c.m_pos + std::min(c.m_oldLen, c.m_len) <= pos + p) {
-                if (c.m_oldLen < c.m_len) {
-                    if (c.m_len - c.m_oldLen >= pos) {
-                        p -= pos;
-                    } else if (c.m_pos - p + changed.first.m_firstPos > changed.first.m_length) {
-                        p -= (pos + p + changed.first.m_firstPos - changed.first.m_length
-                              + (pos >= changed.first.m_length - p + (c.m_len - c.m_oldLen) ? 0 : 1));
-                    } else {
-                        const auto tmp = c.m_len - c.m_oldLen;
+            const auto startPos = c.m_pos;
+            const auto endPos = startPos + c.m_len - 1;
 
-                        p -= tmp - (pos >= c.m_pos && pos < c.m_pos + tmp ? (tmp - pos + c.m_pos) : 0);
-                    }
+            if (pos >= startPos && pos <= endPos) {
+                const auto oldEndPos = startPos + c.m_oldLen - 1;
+
+                if (pos > oldEndPos || end) {
+                    return oldEndPos + changed.first.m_firstPos;
                 } else {
-                    p += (c.m_oldLen - c.m_len);
+                    return pos + changed.first.m_firstPos;
                 }
+            } else if (pos > endPos) {
+                pos += c.m_oldLen - c.m_len;
             } else {
                 break;
             }
         }
 
-        return pos + p + changed.first.m_firstPos;
+        pos += changed.first.m_firstPos;
+
+        return (pos > changed.first.m_length ? changed.first.m_length : pos);
     }
 
     long long int countOfSpacesForTab(long long int virginPos) const
@@ -958,6 +988,16 @@ struct UnicodeStringTrait {
     {
         str.push_back(Char(ch));
     }
+
+    //! Search for last occurrence of string.
+    static long long int lastIndexOf(const String &where, const String &what, long long int from)
+    {
+        if (from < 0) {
+            return -1;
+        } else {
+            return where.lastIndexOf(what, 0, from + 1);
+        }
+    }
 }; // struct UnicodeStringTrait
 
 #endif // MD4QT_ICU_STL_SUPPORT
@@ -1051,6 +1091,16 @@ struct QStringTrait {
     {
         str += QChar::fromUcs4(ch);
     }
+
+    //! Search for last occurrence of string.
+    static long long int lastIndexOf(const String &where, const String &what, long long int from)
+    {
+        if (from < 0) {
+            return -1;
+        } else {
+            return where.lastIndexOf(what, from);
+        }
+    }
 }; // struct QStringTrait
 
 #endif // MD4QT_QT_SUPPORT
